using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using CustomerOrder;
using CustomerOrder.Entities;
using DataLayer.Mapping;

namespace DataLayer
{
  public class CustomerOrderContext : DbContext
  {

    public DbSet<Address> Addresses { get; set; }
    public DbSet<Customer> Customers { get; set; }

    public DbSet<Product> Products { get; set; }
    public DbSet<Category> ProductCategories { get; set; }
    public DbSet<ProductDescription> ProductDescriptions { get; set; }
    public DbSet<ProductModel> ProductModels { get; set; }
    public DbSet<Order> Orders { get; set; }
    public DbSet<LineItem> LineItems { get; set; }
    public DbSet<CustomerLite> CustomerLites { get; set; }

    public override int SaveChanges()
    {
      foreach (var entry in ChangeTracker.Entries()
        .Where(e => e.Entity is DateClass &&
          (e.State == EntityState.Added | e.State == EntityState.Modified)))
      {
        var dateClass = (DateClass)entry.Entity;
        if (entry.State == EntityState.Added)
        {
          dateClass.AddedDate = DateTime.Now;
          dateClass.ModifiedDate = DateTime.Now;

        }
        if (entry.State == EntityState.Modified)
        {
          dateClass.ModifiedDate = DateTime.Now;
        }
      }
      return base.SaveChanges();
    }

    protected override void OnModelCreating(DbModelBuilder modelBuilder)
    {
      modelBuilder.Configurations.Add(new OrderShippingMap());
      modelBuilder.Configurations.Add(new CustomerLiteMap());
      modelBuilder.Configurations.Add(new CustomerMap());
      modelBuilder.Configurations.Add(new OrderMap());
    }
  }

  public class MyInitializer : DropCreateDatabaseIfModelChanges<CustomerOrderContext>
  {

    public MyInitializer()
    {
     //web.config db initialization requires a parameterless constructor.
      var x = 3;
    }
    protected override void Seed(CustomerOrderContext context)
    {
      

      var choc = new Product { Name = "Bittersweet Chocolate", ProductCategory = new Category { Name = "Baking" } };
      var eggs = new Product
                   {
                     Name = "Eggs",
                     ProductCategory = new Category { Name = "Dairy" }
                   };
      var raisins = new Product { Name = "Raisins", ProductCategory = new Category { Name = "Fruit" } };


      new List<Customer>
           {
            new Customer {FirstName = "Julie", MiddleName="H", LastName = "Lerman", CompanyName="The Data Farm", Title="Head Geek", ModifiedDate = DateTime.Now,
                       Orders=new List<Order>
                                  {
                                      new Order
                            {
                              ModifiedDate = DateTime.Now,
                              SalesOrderNumber = "12345",
                              DueDate = DateTime.Today + new TimeSpan(30, 0, 0, 0),
                              OrderDate = DateTime.Today,
                              LineItems=new List<LineItem>
                                          {
                                            new LineItem{Product=choc, OrderQty=4, UnitPrice=3.00m},
                                            new LineItem{Product=eggs,OrderQty=1,UnitPrice=3.50m}
                                          },
                                          SubTotal=16.50m
                            },
                                  
                                     new Order
                            {
                              ModifiedDate = DateTime.Now,
                              SalesOrderNumber = "98765",
                              OrderDate = new DateTime(2011,5,24),
                              DueDate = new DateTime(2011,5,24) + new TimeSpan(30, 0, 0, 0),
                              SubTotal=5.50m,
                              LineItems=new List<LineItem>
                                          {
                                            new LineItem{Product=choc, OrderQty=1, UnitPrice=3.00m},
                                            new LineItem{Product=raisins,OrderQty=1,UnitPrice=2.50m}
                                          }
                            }
                                  }}}.ForEach(c => context.Customers.Add(c));
      base.Seed(context);

    }
  }
}

