﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Phone.Controls;

namespace WP7App
{
  public partial class MainPage : PhoneApplicationPage
  {
    // Constructor
    public MainPage()
    {
      InitializeComponent();

      DataContext = App.ViewModel;
      Loaded += new RoutedEventHandler(MainPage_Loaded);
      App.ViewModel.PropertyChanged += new PropertyChangedEventHandler(PropertyChanged);
      App.ViewModel.SaveStatusChanged += new DataAccess.SaveStatusChangedEventHandler(SaveStatusChanged);
   }

    // Load data for the ViewModel Items
    private void MainPage_Loaded(object sender, RoutedEventArgs e)
    {
      if (!App.ViewModel.IsDataLoaded)
      {
        App.ViewModel.LoadData();

      }
    }


    public void PropertyChanged(object sender, PropertyChangedEventArgs e)
    {
      var propChanged = e.PropertyName;
      switch (propChanged)
      {
        case "Customer":

          Dispatcher.BeginInvoke(() => stackPanel1.DataContext = App.ViewModel.Customer);
          Dispatcher.BeginInvoke(() => lstOrders.ItemsSource = App.ViewModel.Orders);
          break;
      }
    }

    public void SaveStatusChanged(object sender, PropertyChangedEventArgs e)
    {
      var status = e.PropertyName;
      if (e.PropertyName.StartsWith("Error") && !e.PropertyName.Contains("Invalid cross-thread"))
      { status = "Error"; }

      switch (status)
      {
        case "Saved":
          Dispatcher.BeginInvoke(() => SavedGrid.Visibility = System.Windows.Visibility.Visible);
          break;
        case "Error":
          Dispatcher.BeginInvoke(() => savedText.Text = "Error");
          Dispatcher.BeginInvoke(() => SavedGrid.Visibility = System.Windows.Visibility.Visible);
          break;
      }

    }

    private void lstOrders_SelectionChanged(object sender, SelectionChangedEventArgs e)
    {
      // If selected index is -1 (no selection) do nothing
      if (lstOrders.SelectedIndex == -1)
        return;

      // Navigate to the new page
      NavigationService.Navigate(new Uri("/DetailsPage.xaml?selectedItem=" + lstOrders.SelectedIndex, UriKind.Relative));

      // Reset selected index to -1 (no selection)
      lstOrders.SelectedIndex = -1;
    }

    private void Save_Click(object sender, RoutedEventArgs e)
    {
      App.ViewModel.Save();
    }

    private void button2_Click(object sender, RoutedEventArgs e)
    {
      savedText.Text = "Saved!";
      SavedGrid.Visibility = Visibility.Collapsed;
    }
  }
}